# Table of Contents

- [discovering-ai-agents-from-google-agent-engine](<./discovering-ai-agents-from-google-agent-engine.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Discovering AI Agents from Google Agent Engine](<./Discovering-AI-Agents-from-Google-Agent-Engine.md>)
  - [Overview](<./Discovering-AI-Agents-from-Google-Agent-Engine/Overview.md>)
  - [Scope](<./Discovering-AI-Agents-from-Google-Agent-Engine/Scope.md>)
  - [Limitations](<./Discovering-AI-Agents-from-Google-Agent-Engine/Limitations.md>)
  - [Prerequisites](<./Discovering-AI-Agents-from-Google-Agent-Engine/Prerequisites.md>)
  - [Step 1: Create a Service Account in the Google Cloud Console](<./Discovering-AI-Agents-from-Google-Agent-Engine/Step-1-Create-a-Service-Account-in-the-Google-Cloud-Console.md>)
  - [Step 2: Generate and Download a JSON Key](<./Discovering-AI-Agents-from-Google-Agent-Engine/Step-2-Generate-and-Download-a-JSON-Key.md>)
  - [Step 3: Connect SAP LeanIX to Google Agent Engine](<./Discovering-AI-Agents-from-Google-Agent-Engine/Step-3-Connect-SAP-LeanIX-to-Google-Agent-Engine.md>)
  - [Linking Discovered Items to Fact Sheets](<./Discovering-AI-Agents-from-Google-Agent-Engine/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./Discovering-AI-Agents-from-Google-Agent-Engine/Viewing-Synchronization-Logs.md>)
  - [Was this page helpful?](<./Discovering-AI-Agents-from-Google-Agent-Engine/Was-this-page-helpful.md>)
